import Vue from "vue";
import Polyglot from "node-polyglot";

import de from '@/i18n/de'
import en from '@/i18n/en'

export const translationVm = new Vue({
    created() {
        const potentialLocale = navigator.language.substring(0, 2)
        this.activeLocale = this.availableLocales.hasOwnProperty(potentialLocale) ? potentialLocale : 'de'

        const phrases = this.availableLocales[this.activeLocale];
        this.polyglot = new Polyglot({ phrases })
    },

    data() {
        return {
            availableLocales: { de, en },
            activeLocale: 'de',
            polyglot: null,
        }
    },

    methods: {
        getPhrasesForLocale(locale) {
            return this.availableLocales[locale];
        },

        locale(newLocale) {
            const phrases = this.getPhrasesForLocale(newLocale)

            this.activeLocale = newLocale
            this.polyglot = new Polyglot({ phrases })
            this.polyglot.locale(newLocale)
        },

        t(text, context = {}) {
            return this.polyglot.t(text, context);
        }
    },
})

export default {
    install(Vue) {
        Vue.prototype.$activeLocale = () => translationVm.activeLocale

        Vue.prototype.$locale = function (newLocale) {
            translationVm.locale(newLocale)
        }

        Vue.prototype.$t = function (text, context = {}) {
            return translationVm.t(text, context)
        }
    }
}
